
# space-for-everyone

<img src="https://i.ibb.co/JW8JZzWn/logo-nobg.png" alt="space-for-everyone Logo" width="120" height="120">


![PyPI](https://img.shields.io/pypi/v/space-for-everyone)
![Python](https://img.shields.io/pypi/pyversions/space-for-everyone)
![License](https://img.shields.io/badge/License-MIT-blue)

Host anywhere and anytime — get **instant direct links** for your files

---

## Install

```bash
pip install space-for-everyone
```

> Make sure you have Python 3.8+ installed.

---

## Usage

Upload a single file and get the direct link:

```bash
host myfile.png
```

Optionally, you can **copy the link to your clipboard** if `pyperclip` is installed:

```bash
host myfile.png --copy
```

---
## Author

Sid & kan — sofiyasenthilkumar@gmail.com

---

## License

This project is licensed under the **MIT License**. See the LICENSE file for details.

